# The gSeaGen code

The gSeaGen code is a GENIE based application developed to efficiently generate high statistics of the 
neutrino interaction events detectable in the neutrino telescopes. The gSeaGen code is able to generate 
events induced by all neutrino flavours, considering topological differences between track-type and 
shower-like events. The neutrino interaction is simulated taking into account the density and the 
composition of the media surrounding the detector.

The gSeaGen code is developed whitin the KM3NeT Collaboration (https://www.km3net.org)

For more information about GENIE, visit http://www.genie-mc.org

For more information about gSeaGen, see [this document](https://simulation.pages.km3net.de/gseagen/gseagen.pdf)

For specific information on processing of CORSIKA files with gSeaGen (and some major changes that were done there), see [this document](https://simulation.pages.km3net.de/gseagen/CORSIKA_processing_with_gSeaGen.pdf)


## Authors

Carla Distefano, INFN-LNS, Via S.Sofia 62, 95123, Catania, Italy (e-mail: distefano_c@lns.infn.it)

Alfonso Andres Garcia Soto, Nikhef, Science Park 904, Amsterdam 1098 XH, Netherlands (e-mail: alfonsog@nikhef.nl)

## Copyright

Copyright (c) 2012-2020, The KM3NeT Collaboration. For information see the file LICENSE

## Installing

The gSeaGen compiling requires a linux-like operating system and some basic tools, 
such as the `gcc` compiler suite, `make` and `PERL`.
A minimal installation of gSeaGen requires only GENIE (visit http://www.genie-mc.org). 

A number of environmental variables must be defined to compile gSeaGen:

`GSEAGEN`  pointing at the top level gSeaGen directory

`GENIE`  pointing at the top level GENIE directory

`ROOTSYS`  pointing at the top level ROOT directory

gSeaGen has been written using the GENIE Auk production release series and tested with GENIE version 2.12.10. 
It is also possible to link gSeaGen with the new Bear release series (GENIE v3.0.0 and later). 
In this case the GENIE environmental variables for the compilation are:

`GENIE`  pointing at the top level GENIE Generator directory

`GENIE_REWEIGHT`  pointing at the top level GENIE Reweight directory

Once the environmental variables are set, a minimal installation of gSeaGen is obtained typing:

```
$ cd $GSEAGEN
$ ./configure
$ make 
```

The configuration script allows to enable/disable features and specify paths to external libraries as 
the `MUSIC` and `PROPOSAL` propagators.
The command:

```
$ ./configure --help
```
lists the configuration options.
The configuration script also creates the shell scripts setenv.sh and setenv.csh, helping the user to 
prepare the environment to run the code.


## Usage

To set the environment configuration required to run gSeaGen, the setenv script must be executed: 

```
$ source $GSEAGEN/setenv.csh (in tcsh or csh shells)
$ source $GSEAGEN/setenv.sh (in bash shell)
```

The environmental variables required by GENIE and the ROOT version used during the compilation step are also  set.
Finally, the user can run the code with the following syntax:

```
$ gSeaNuEvGen [OPTIONS]
```
Running the code with the option ```-h``` (i.e. ```$ gSeaNuEvGen -h```), the code writes the list of the available options: 


```
**Syntax**
 gSeaNuEvGen 
           [-a generation_spectral_index]
           [-all]
           [-b n_of_bins]
           [-bedrock bedrock_height]
           [-c can_definition]
           [-C]
           [--coord UNIT:longitude,latitude]
           [--cross-sections XSecName]
           [-d depth]
           [-e min_energy,max_energy]
           [--event-generator-list list_name]
            -f simulation:flux[neutrino_code],...
           [-l light_absorption_lenght,[n_light_absorption_lenght]]
            -n n_of_events
           [-o output_event_file_prefix]
           [-origin X0,Y0,Z0]
           [-p]
           [-point source_info]
           [-prop prop_code]
           [-r run_number]
           [-R coordinate_rotation_matrix]
           [-rt RT_option]
           [--seed random_number_seed]
	   [-utm]
           [-t min_costheta,max_costheta]
	   [-time time_format:StartTime,StopTime]
           [-tree tree_format]
           [--tune generator_tune]
           [-w]
           [-save saved_particles]
           [-chances chances_per_shower]"
           [--rot-showers UNIT:yaw,pitch,roll]"
           [-wgt weighting scheme]
           [--cr-flux CR flux model used to weight CORSIKA events]

 **Code Options**

 [] Denotes an optional argument.

 -a        Specifies the generation spectral index [default: 1.4].

 ...
 
 ...

**Environmental Parameters**

 GSeaGen environmental parameters: 

 GSEAGEN:     pointing to the top directory of the code [mandatory]. 

 MUSICPATH:   pointing to the directory with music input files [default: MUSICPATH = /pbs/throng/km3net/src/gSeaGen/music/2004]. 

 GMURNGFL:    pointing to file with max muon ranges [default: GMURNGFL = $GSEAGEN/dat/muon_rmax_music.dat]. 

 MEDIACOMP:   overriding the default composition for target media: SeaWater, Rock, Mantle, Crust.
                  Eg. MEDIACOMP = $GSEAGEN/dat/MediaComposition.xml 

 PROPOSALCONF: pointing to the PROPOSAL configuration file. Default inputs are used if the env. parameter does not exist.
                  Eg. PROPOSALCONF = proposaldir/resources/config.json

 SYSTLIST:    pointing to the file defining the systematic parameters. The calculation is activated if the env. parameter exists.
                  Eg. SYSTLIST = $GSEAGEN/dat/SystParams.xml 

 Based on GENIE, gSeaGen accepts all standard GENIE environmental parameters. For examples: 

 GALGCONF:    overriding the default configuration folder [default: GALGCONF = $GENIE/config]
                  Eg. GALGCONF = $GENIE/config 
              to use the default GENIE configuration folder. 

 GXMLPATH:    to get user XML input files using GXMLPATH + default locations.
 
``` 
gSeaGen running requires a GENIE pre-computed cross section file. Official GENIE cross sections or instructions for building your own are available at http://www.genie-mc.org.
By default, gSeaGen looks for the gxspl-FNALsmall.xml file in the running directory or in the one pointed by the GXMLPATH environmental variable as standard in GENIE. 

### Examples:

*  gSeaNuEvGen -n 1E3 -f [14] 

The code will generate a number of 1000 arrival muon neutrinos form a diffuse flux according to a power-low energy spectrum with spectral index -1.4. 
The code will also compute a weight for each event to normalize the simulation to the flux 1E-9*E-2 1/(GeV m2 s sr). Default values will be used for any other possible option.

gSeaGen accepts as input official BARTOL, FLUKA and HONDA atmospheric muon fluxes. Some of them are in the $GSEAGEN/dat directory and described in the $GSEAGEN/FLUX file.

*  gSeaNuEvGen -n 1E3 -f "HONDA:$GSEAGEN/dat/grn-ally-20-12-solmin.d[14,-14]" 

In this case both muon neutrinos and anti-neutrinos will be generated and the events weights will be computed according to the HONDA fluxes in the file grn-ally-20-12-solmin.d.

It is possible to generate neutrinos from point or extended astrophysical sources. To activate this mode and to input the source informations, the running option -point is used. 

*  gSeaNuEvGen -n 1E3 -f [14] -point "FILE:$GSEAGEN/dat/AstroSource.xml"

In this case, the arrival neutrinos are generated form the source defined in the file $GSEAGEN/dat/AstroSource.xml that can be used as a reference. When the point/extended mode is activated, gSeaGen uses the detector geographical coordinates. To set the detector coordinates uses option –coord. 

CORSIKA output files (DATxxx) may be used as input for gSeaGen. For this you need 

*  gSeaNuEvGen -f "BIN:$DIR/DAT$RUN"

for direct readout and

*  gSeaNuEvGen -f "EVT:$DIR/DAT$RUN.evt"

to read from CORSIKA files processed with [corant](https://git.km3net.de/simulation/corant).


## Citing gSeaGen

References: 

[S. Aiello et al. (the KM3NeT Collaboration), Computer Physics Communications 256, 107477 (2020)](https://doi.org/10.1016/j.cpc.2020.107477) 

[C. Distefano for the ANTARES and KM3NeT Collaborations, EPJ Web of Conferences 116, 08001 (2016)](https://doi.org/10.1051/epjconf/201611608001) 	 

gSeaGen is GENIE based application. For information about GENIE citing rules visit 
https://hep.ph.liv.ac.uk/~costasa/genie/citing.html




