//____________________________________________________________________________
/*!

\class   PropaUtils

\brief   Muon track data for PropaMuon class 

\author  Carla Distefano <distefano_c@lns.infn.it>
         LNS-INFN, Catania

\created December 9, 2015

\cpright  Copyright (c) 2015-2019, The KM3NeT Collaboration 
          For the full text of the license see $GSEAGEN/LICENSE
*/
//____________________________________________________________________________


#ifndef _GPROPATRACKS_H__
#define _GPROPATRACKS_H__

#include <vector>
#include <iostream>

using namespace std;

struct PropaTrack {

  unsigned  Id;                 ///< Unique identifier       
  int       Status;             ///< Genie status propagation (+1000 if it is used for propagation)
  int       Pdg;                ///< Pdg code
  int       MotherId;           ///< Mother unique identifier
  double    V1,V2,V3;		///< Position 
  double    D1,D2,D3;		///< Direction 
  double    E;          	///< Energy
  double    Length;     	///< Length
  double    T;      		///< time  of passage trough position
  
  void DirectionCosines(){
  
    if(fabs(D1)>1)cout<<"direction cosine x out of range after propagation. Direction will be renormalized. "<<D1<<endl;
    if(fabs(D2)>1)cout<<"direction cosine y out of range after propagation. Direction will be renormalized. "<<D2<<endl;
    if(fabs(D3)>1)cout<<"direction cosine z out of range after propagation. Direction will be renormalized. "<<D3<<endl;
    
    double norma = sqrt(pow(D1,2)+pow(D2,2)+pow(D3,2));
    
    D1 /= norma;
    D2 /= norma;
    D3 /= norma;
    return;
  }

};

typedef vector<PropaTrack> PropaTracks;

#endif // _GPROPATRACKS_H__

