//____________________________________________________________________________
/*!

\class   PropaUtils

\brief   Utilities for PropaMuon class 

\author  Carla Distefano <distefano_c@lns.infn.it>
         LNS-INFN, Catania

\created December 9, 2015

\cpright  Copyright (c) 2015-2019, The KM3NeT Collaboration 
          For the full text of the license see $GSEAGEN/LICENSE
*/
//____________________________________________________________________________

#ifndef _PROPAUTILS_H__
#define _PROPAUTILS_H__


#include <TMath.h>

namespace propamuon {


  static const double kProtonMass     =  0.9382720;           // GeV
  static const double kElectronMass   =  0.0005109989;        // GeV
  static const double kMuonMass       =  0.105658357;         // GeV
  static const double kTauMass        =  1.77703;             // GeV

  static const double kElectronMass2  =  TMath::Power(kElectronMass,2); // GeV^2
  static const double kMuonMass2      =  TMath::Power(kMuonMass,2);     // GeV^2
  static const double kTauMass2       =  TMath::Power(kTauMass,2);      // GeV^2

  static const double kMuonElectronMass =  kMuonMass/kElectronMass;     

  static const double kMuonElectronMass2 =  TMath::Power(kMuonElectronMass,2);     


  static const double kAem   = 1./137.03599976;       // EM coupling const, dimensionless
  static const double kAem2  = TMath::Power(kAem,2);
  static const double kAem3  = TMath::Power(kAem,3);
  static const double kAem4  = TMath::Power(kAem,4);


  static const double kPi    = 3.1415927;
  static const double ke     = 2.7182818;
  static const double kSqrte = TMath::Sqrt(ke);

  static const double kNA    = 6.02214179E+23;             
  static const double kLe    = 3.8616E-11;	// electron Compton wavelength cm
  static const double kLe2   = TMath::Power(kLe,2);          
  
  static const double kRe    = 2.8179403267E-13;       // cm




  int  PdgToZ      (int pdgc);
  int  PdgToA      (int pdgc);  

}      // propamuon namespace

#endif // _PROPAUTILS_H__
