//____________________________________________________________________________
/*!

\class   genie::GSeaEvent

\brief   A class for generated event by gSeaGen

\author  Carla Distefano <distefano_c@lns.infn.it>
         LNS-INFN, Catania
         Included modifications by Alfonso Garcia <alfonsog@nikhef.nl>
         NIKHEF, Amsterdam (January 2019)

\created November 25, 2015

\cpright  Copyright (c) 2015-2019, The KM3NeT Collaboration
          For the full text of the license see $GSEAGEN/LICENSE

*/
//____________________________________________________________________________
#ifndef _GSEAEVENT_H__
#define _GSEAEVENT_H__

#include "TObject.h"
#include "TLorentzVector.h"

#include "PropaMuon/PropaTracks.h"
#include "SeaEvent/GBinParam.h"
#include "SeaEvent/GSeaTrack.h"
#include "SeaNuDrivers/GSeaSyst.h"

using namespace std;


class GSeaEvent : public TObject {

  public:

  int iEvt;
  int iEvtMC;

  int NInter;

  double PScale;
  int VerInCan;
  bool LepInCan;

  double SWXSec;      // total cross section per nucleon in pure water in m^2
  double WaterXSec;   // total cross section per nucleon in pure water in m^2
  double WaterIntLen; // interaction lenght in pure water in m

  int TargetA;
  int TargetZ;
  int InterId;
  int ScattId;
  double Bx;
  double By;
  double XSec;
  double DXSec;

  TLorentzVector Vertex;

  GSeaTrack EarthNeutrino;

  GSeaTrack Neutrino;
  GSeaTrack PrimaryLepton;
  vector<GSeaTrack> Tracks;
  int NTracks;
  int NRetries;

  double GenWeight;
  double EvtWeight;
  SystWeights SysWgt;

  double Agen;
  double PEarth;
  double ColumnDepth;
  double XSecMean;

  double DistaMax;

  double LST;
  double MJD;

  unsigned int EvtTime[2];

  GSeaEvent();
  ~GSeaEvent();

  void Copy(GSeaEvent * SeaEvt);
  void Reset(void);

  void Translate(double X0, double Y0, double Z0);

  ClassDef(GSeaEvent,1);

  private:
  static TClonesArray *fgTracks;

};

#endif // _GSEAEVENT_H__
