//____________________________________________________________________________
/*!

\class   genie::GSeaTrack

\brief   A class to store track info

\author  Carla Distefano <distefano_c@lns.infn.it>
         LNS-INFN, Catania
         Included modifications by Alfonso Garcia <alfonsog@nikhef.nl>
	 NIKHEF, Amsterdam (January 2019)

\created December 1, 2015

\cpright  Copyright (c) 2015-2019, The KM3NeT Collaboration
          For the full text of the license see $GSEAGEN/LICENSE

*/
//____________________________________________________________________________


#ifndef _GSEATRACK_H_
#define _GSEATRACK_H_

#include "TLorentzVector.h"

using namespace std;


class GSeaTrack : public TObject {

public :

  GSeaTrack();
  ~GSeaTrack();
  void Reset(void);
  void Set(int id, int status, int pdg, int motherid, double Mass, TLorentzVector * VecEne, TLorentzVector * VecPos, TLorentzVector * IntVer, double length, int gencounter, double pendepth);
  void Translate(double X0, double Y0, double Z0);
  void Print();

  unsigned  Id;                 ///< Unique identifier
  int       Status;             ///< Genie status propagation (+1000 if it is used for propagation)
  int       PdgCode;            ///< Pdg code
  int       MotherId;           ///< Mother unique identifier
  double    E;                  ///< Energy
  double    V1,V2,V3;           ///< Position
  double    D1,D2,D3;           ///< Direction
  double    Length;             ///< length travel by particle (relevant for propagated tracks)
  double    T;                  ///< time  of passage trough position
  int GenCounter;               ///< generation counter (CORSIKA-specific particle history information)
  double PenDepth;              ///< penetration depth [g/cm^2] (CORSIKA-specific)

protected :

  ClassDef(GSeaTrack,1);

};

#endif // _PEARTH_H_
