//____________________________________________________________________________
/*!

\class   genie::flux::GSeaCORSIKAFileFlux

\brief   A flux driver to read incident muons and neutrinos from CORSIKA7 binary files

\author  Piotr Kalaczyński <piotr.kalaczynski@ncbj.gov.pl>
         NCBJ Warsaw

\created 25.12.2020

\cpright  Copyright (c) 2020, The KM3NeT Collaboration
          For the full text of the license see $GSEAGEN/LICENSE

*/
//____________________________________________________________________________

#ifndef _GSEA_CORSIKA_FILE_FLUX_I_H_
#define _GSEA_CORSIKA_FILE_FLUX_I_H_

#include "SeaNuDrivers/GSeaFileFlux.h"

namespace genie {
namespace flux  {

class GSeaCORSIKAFileFlux: public GSeaFileFlux {

public:
  GSeaCORSIKAFileFlux(GenParam * GenPar);

 ~GSeaCORSIKAFileFlux();

 int CorsikaToPdg(int CORSIKAId);
 double CorsikaRestMass(int CORSIKAId);
 double CRFlux(double PrimEnergy, int PrimCORSIKAId, string CRFluxModel);

private:

  ifstream CORSIKAFile;

  vector<GSeaTrack> ReadFileEvent(void);

  // Declaration of parameters needed to read the CORSIKA files
  const static int NRecStd = 22940;           // "standard CORSIKA" record size,
                                       //        ThiData[0] = 6.08270e-311
                                       //    or  ThiData[0] = 3.213456e-41
  const static int NRecThi = 26216;           // "thinning CORSIKA" record size,
                                       //        ThiData[0] = 6.95166e-311
                                       //    or  ThiData[0] = 3.672523e-41
  const static int NDim = 20000000;
  const static int NumSubblocks = 21;         // number of subblocks
  const static int LenSubblStd = 273;         // subblock length in words (standard)
  const static int LenSubblThi = 312;         // subblock length in words (thinning)
  const static int NumStd = 5735;             // =  NRecStd / 4
  const static int NumThi = 6554;             // =  NRecThi / 4
  unsigned int LenSubblock, LBit, LThi,nShow,nRun,iRec,lp;
  int PrimID;
  double MinEPrim,MaxEPrim,EPrim;
  float EPrimSlope;

  // no point to use double here since CORSIKA saves the output with single precision
  float ThiData[NumThi];               // single corsika record thinned data
  float StdData[NumStd];               // single corsika record standard data
  float HData[819];                    // end of 1st corsika record thinned data
  float ZData[2];                      // record length info on 64bit machines

};

} // flux namespace
} // genie namespace

#endif // _GREAL_FILE_FLUX_I_H_
